#
# spec file for package libnvidia-container
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 1
%define modprobe_version 495.44

Name:           libnvidia-container
Version:        1.11.0
Release:        150200.5.6.1
Summary:        NVIDIA container runtime library
License:        BSD-3-Clause AND Apache-2.0 AND GPL-3.0-or-later AND LGPL-3.0-or-later AND MIT AND GPL-2.0-only
# elftoolchain is licensed under BSD-3-Clause
#  https://github.com/elftoolchain/elftoolchain#copyright-and-license
# libnvidia-container is licensed under apache-2.0
#  https://github.com/NVIDIA/libnvidia-container/blob/master/LICENSE
# libnvidia-container includes the GLPv3 license
#  https://github.com/NVIDIA/libnvidia-container/blob/master/COPYING
# libnvidia-container includes the LGPLv3 license
#  https://github.com/NVIDIA/libnvidia-container/blob/master/COPYING.LESSER
# nvidia-modprobe is licensed under GPLv2
#  https://github.com/NVIDIA/nvidia-modprobe/blob/master/COPYING
# several nvidia-modprobe files contain the MIT license header
#  https://github.com/NVIDIA/nvidia-modprobe/blob/master/utils.mk
URL:            https://github.com/NVIDIA/libnvidia-container
Source:         libnvidia-container-%{version}.tar.xz
Source1:        https://github.com/NVIDIA/nvidia-modprobe/archive/%{modprobe_version}.tar.gz#/nvidia-modprobe-%{modprobe_version}.tar.gz
Patch1:         libnvidia-container-fix-makefile.patch
Patch2:         no-manual-debuginfo.patch
BuildRequires:  bmake
BuildRequires:  curl
BuildRequires:  distribution-release
BuildRequires:  git
BuildRequires:  go-go-md2man
BuildRequires:  golang(API) >= 1.16
BuildRequires:  golang-packaging
BuildRequires:  groff
BuildRequires:  libcap-devel
BuildRequires:  libelf-devel
BuildRequires:  libseccomp-devel
BuildRequires:  libtirpc-devel
BuildRequires:  lsb-release
BuildRequires:  m4
BuildRequires:  rpcgen
ExcludeArch:    i586 s390x

%description
The nvidia-container library provides an interface to configure GNU/Linux
containers leveraging NVIDIA hardware. The implementation relies on several
kernel subsystems and is designed to be agnostic of the container runtime.

%package -n %{name}%{sover}
Summary:        NVIDIA container runtime library

%description -n %{name}%{sover}
The nvidia-container library provides an interface to configure GNU/Linux
containers leveraging NVIDIA hardware. The implementation relies on several
kernel subsystems and is designed to be agnostic of the container runtime.

This package requires the NVIDIA driver (>= 340.29) to be installed separately.

%package devel
Summary:        NVIDIA container runtime library (development files)
Requires:       %{name}%{sover} = %{version}-%{release}

%description devel
The nvidia-container library provides an interface to configure GNU/Linux
containers leveraging NVIDIA hardware. The implementation relies on several
kernel subsystems and is designed to be agnostic of the container runtime.

This package contains the files required to compile programs with the library.

%package static
Summary:        NVIDIA container runtime library (static library)
Requires:       %{name}-devel = %{version}-%{release}

%description static
The nvidia-container library provides an interface to configure GNU/Linux
containers leveraging NVIDIA hardware. The implementation relies on several
kernel subsystems and is designed to be agnostic of the container runtime.

This package requires the NVIDIA driver (>= 340.29) to be installed separately.

%package tools
Summary:        NVIDIA container runtime library (command-line tools)
Requires:       %{name}%{sover} >= %{version}-%{release}

%description tools
The nvidia-container library provides an interface to configure GNU/Linux
containers leveraging NVIDIA hardware. The implementation relies on several
kernel subsystems and is designed to be agnostic of the container runtime.

This package contains command-line tools that facilitate using the library.

%prep
%setup -q -T -D -b 0 -a 1 -n libnvidia-container-%{version}
%patch1 -p1
%patch2 -p1

%build
# META_NOECHO=echo is required to work around a bug in Leap 15's version of bmake,
# see also https://github.com/ptt/pttbbs/issues/30
export META_NOECHO="echo"
export REVISION=%{version}
REVISION=%{version} make distclean

# NVIDIA modprobe configuration based on mk/nvidia-modprobe.mk
mkdir -p deps/src/nvidia-modprobe-%{modprobe_version}
tar -v -C deps/src/nvidia-modprobe-%{modprobe_version} --strip-components=1 -xz nvidia-modprobe-%{modprobe_version}/modprobe-utils -f %{SOURCE1}
patch -d deps/src/nvidia-modprobe-%{modprobe_version} -p1 < mk/nvidia-modprobe.patch
touch deps/src/nvidia-modprobe-%{modprobe_version}/.download_stamp

%make_build REVISION=%{version} WITH_LIBELF=yes

%install
# META_NOECHO=echo is required to work around a bug in Leap 15's version of bmake,
# see also https://github.com/ptt/pttbbs/issues/30
export META_NOECHO="echo"
make install DESTDIR=%{buildroot} REVISION=%{version} WITH_LIBELF=yes \
             LDCONFIG=/bin/true \
             prefix=%{_prefix} \
             exec_prefix=%{_exec_prefix} \
             bindir=%{_bindir} \
             libdir=%{_libdir} \
             includedir=%{_includedir} \
             docdir=%{_licensedir}

# Add the missing link
ln -s libnvidia-container.so.%{version} %{buildroot}%{_libdir}/libnvidia-container.so.1

%post -n %{name}%{sover} -p /sbin/ldconfig
%postun -n %{name}%{sover} -p /sbin/ldconfig

%files -n %{name}%{sover}
%doc README.md 
%license %{_licensedir}/*
%{_libdir}/libnvidia-container.so.*
%{_libdir}/libnvidia-container-go.so
%{_libdir}/libnvidia-container-go.so.*

%files devel
%{_includedir}/nvc.h
%{_libdir}/libnvidia-container.so
%{_libdir}/pkgconfig/libnvidia-container.pc

%files static
%{_libdir}/libnvidia-container.a

%files tools
%{_bindir}/nvidia-container-cli

%changelog
* Mon Oct 10 2022 mjura@suse.com
- Exclude build for arch i586
- Remove libnvidia-container-fix-revision.patch
- Update to version 1.11.0 (jsc#SLE-18750):
  * Bump version to 1.11.0
  * Update release date
  * Properly specify fedora35 artifact dir
  * Fix format string
  * Switch to centos:stream8 container for fedora
  * Add missing changelog entry
  * Add fedora35 CI steps
  * Add support for fedora35
  * Bump version to 1.11.0-rc.3
  * Also change directory when not running pivot root
  * Bump version to 1.11.0-rc.2
  * Bump version to 1.11.0-rc.1
  * Preload libgcc_s.so.1 on arm64 systems
  * Switch to latest docker and docker dind in CI
  * Bump version to v1.10.0
  * Bump version to 1.10.0-rc.4
  * Bump github.com/opencontainers/runc from 1.0.3 to 1.1.2 in /src/nvcgo
  * Fix bug introduced when adding libcudadebugger.so to list of libraries
  * Bump version to 1.10.0-rc.3
  * Add libcudadebugger.so to list of compute libraries
  * Fix bug when running host ldconfig using glibc compiled with a non-standard prefix
  * Correct whitespace in changelog
  * Bump libtirpc to 1.3.2
  * Bump libtirpc to 1.3.2
  * Change master references to main
  * Bump version to v1.10.0-rc.2
  * Add option --setopt=best=0 to centos and amazonlinux builds
  * Remove unneeded rpm-sign package from centos and al docker files
  * Set returned error context to output error to stdout
  * Exit with error if dxcore initializes with no adapters found
  * Revert "Log error and skip dxcore initialization if no adapters are found"
  * Ignore pending MIG mode when checking whether MIG is enabled
  * Fix typos in comments and changelog
  * Switch from centos:8 to centos:stream8 images to build centos8 packages
  * [CI] Add CI job for each distribuition-arch combination
  * Skip filtering devices based on capability on WSL2
  * Log error and skip dxcore initialization if no adapters are found
  * Bump version to 1.10.0-rc.1
  * Bump version to 1.9.0
  * Update Changelog
  * Add additional check for Tegra in /sys/.../family file in CLI
  * Update changelog
  * Change default jetpack-specific CLI option for loading base CSV files
  * Ensure that firmware paths are mounted at /lib in the container
  * Factor out mount code to accept explicit source and destination
  * Update Changelog
  * Update switch statement to include new brands from latest nvml.h
  * Update NVML to "CUDA 11.6.1 nvML_DEV 11.6.55"
  * Fix logic to process --require flags on Jetson platforms
  * Bump version to 1.9.0-rc.1
  * Fix centos8 build
  * Update (placeholder) changelog for 1.8.2-1
  * Add symlink for /dev/fd --> /proc/dev/fd when doing ldconfig in chroot
  * Update changelog
  * Fix bug where cgroup mount prefix not stripped from cgroup root
  * Bump version to 1.8.1
  * Add NVC_CONTAINER caps around cgroup version and find_cgroup_path calls
  * Bump version to 1.8.0
  * Remove amazonlinux1 build targets
  * Bump version to 1.8.0-rc.3
  * Specify docker platform args for build and run commands
  * Update centos8 mirrors
  * Update changelog
  * Include libnvidia-pkcs11.so in compute libraries
  * Support writing entire device filter eBPF program (if none present)
  * Remove custom code for getting existing eBPF program for device filters
  * Update cgroupv2 code to use cilium/ebpf to get existing eBPF program
  * Update celium/ebpf dependency to 0.8.0 in nvcgo
  * Include firmware paths in list command
  * Rename (n)dirs members to (n)firmwares
  * Fix permissions when mounting GSP firmware
  * Fix bug to support cgroupv2 on linux kernels < 5.5
  * Bump version to 1.8.0-rc.2
  * Fix bug in cgroupv2 logic when in mixed v1 / v2 environment
  * Set WITH_NVCGO=yes in mk/docker.mk
  * Bump github.com/opencontainers/runc from 1.0.2 to 1.0.3 in /src/nvcgo
  * Turn on WITH_NVCGO feature gate by default
  * Update changelog for 1.8.0-rc.1
  * Allow build-all jobs to be triggered earlier
  * Ensure that artifact directory exists for docker build
  * Suppress lintian warnings regarding exported symbols
  * Install libnvidia-container-go from deps
  * Fix DESTDIR for deps make target
  * Do a blanket s/ctx/rpc/ over rpc.c to make it clear what type we have
  * Introduce rpc_prog struct to wrap fields for defining an RPC program
  * Cleanup the nvc_shutdown() path when there is an error in RPC services
  * Add notion of "progname" to RPC service for better logging and errors
  * Add CAP_NET_ADMIN to NVC_MOUNT permissions
  * Explicitly set CAP_EFFECTIVE to NVC_MOUNT when setting device rules
  * Add new cgroup.c file to support both cgroupv1 and cgroupv2
  * Move cgroup.c to cgroup_legacy.c in preparation for nvcgo implementation
  * Add new RPC server for running commands from the nvcgo library
  * Add nvcgo library that can be called from C for running Go code
  * Add vendor folder in preperation for new nvcgo package
  * Bump post 1.7.0 release
  * Move nvml_path into driver context instead of explicit RPC argument
  * Move logic to chroot and drop privileges from RPC init into driver init
  * Move src/driver_rpc.x -> src/nvc_rpc.x to accomodate more RPC programs
  * Move from an nvc_context specific RPC driver service to a global one
  * Rename rpc->rpc_* to just rpc->*
  * Split parts of driver_init/shutdown() into rpc_init/shutdown()
  * Split parts of driver.{c,h} into rpc.{c,h}
  * Rename 'driver' service definitions to 'rpc' service definitions
  * Move initialization of driver->nvml_dl to RPC handler of driver_init()
  * Make RPC prognum, versnum, and dispatch function part of driver context
  * Bump version to 1.7.0
  * Add -fplan9-extensions to Makefile for future use
  * Remove the unreferenced declaration of device_mig_device in driver.h
  * Make device_handles struct in driver.c static
  * Add replacement for versions in debian symbol file
  * Bump post 1.7.0-rc.1 release
  * Move SONAME_LIBNVML and SONAME_LIBCUDA to nvc_internal.h
  * Remove erroneous cuda_dl field in 'struct driver'
  * Remove erroneous "unused parameter" warning
  * Fix typos in changelog
  * Update changelogs
  * Add dependency on libnvidia-container0 on ubuntu18.04-arm64
  * Update flags in CLI to be library version specific (as necessary)
  * Correctly bump NVC_MINOR to 7
  * Add make logic to check that version is correctly specified
  * Separate cli-version from lib-version in version output of CLI
  * Backport some CLI configurations from the jetson branch to the mainline
  * Dynamically load v0 of libnvidia-container when on tegra without NVML
  * Fix typo in rpm changelog
  * Only print device paths in the CLI list command if path != NULL
  * Move to calling all NVC functions through function pointers
  * Bump for post 1.6.0 development
  * Bump version to 1.6.0
  * Bump nvidia-modprobe version to 495.44
  * Bump version post 1.6.0-rc.2 release
  * Fix bug for missing files in /proc/driver/nvidia
  * Bump version to 1.6.0-rc.2
  * Add aarch64 build for Amazon Linux 2
  * Introduce a get_cgroup_version() call to the cgroupp API
  * Update cgroup API to be device specific
  * Refactor cgroup logic into its own set of files
  * Update major, minor, and patch version
  * Bump for post v1.5.1 development
  * Bump version to 1.5.1
  * Use defined root when resolving firmware path
  * Free allocated dirs
  * Update changelogs for merged changes
  * Allow to override build date with SOURCE_DATE_EPOCH
  * getpgrp is required to run  nvcr.io/nvidia/tensorrt:20.12-py3
  * Bump for post v1.5.0 development
  * Add NVC_TAG to version header file
  * Bump version to 1.5.0
  * Only copy .deb and .rpm files to dist folder
  * Allow REVISION to be specified as a make variable
  * Correct debian version tag
  * Bump version to 1.5.0~rc.2
  * Read TAG from version string
  * Revert "Mount nvlink and nvswitch devices into container"
  * Revert "Add --fabric-device option to select nvlink and nvswitch devices"
  * Revert "Check for pointer null before strcmp"
  * Check for pointer null before strcmp
  * lseek64/_llseek is required for ldconfig
  * Bump version to 1.5.0~rc.1
  * Mount NVIDIA firmware directory if present
  * Add --fabric-device option to select nvlink and nvswitch devices
  * Mount nvlink and nvswitch devices into container
  * Add dist and .vscode to gitignore
  * Use pmake and bmake from mageia 7.1 in amazonlinux build
  * WSL - Add code to map the binaries from the driver store if they are redistributed with the display driver
  * WSL - Add code to map the binaries from the driver store if they are redistributed with the display driver
  * Explicitly check whether branch is a tag before releasing to Artifactory
  * Add release step to Jenkinsfile
* Wed Jul 14 2021 mjura@suse.com
- Update libnvidia-container to 1.4.0
- Update nvidia-modprobe to 450.57
* Wed Jun  3 2020 comurphy@suse.com
- Update to version 1.1.1
- Fix libnvidia-container-fix-makefile.patch for SLE15
* Tue May 26 2020 idonmez@suse.com
- Cleanup the spec file, fully unbundle elftoolchain part.
- Add no-manual-debuginfo.patch, we automatically generate it.
* Tue May 19 2020 comurphy@suse.com
- Fix libnvidia-container-tools runtime dependencies
* Wed Apr 22 2020 sgrunert@suse.com
- Remove vendored libtirpc and add
  libnvidia-container-fix-makefile.patch as substitution
* Wed Apr  8 2020 sgrunert@suse.com
- Update to version 1.0.6
- Fix build for tumbleweed
* Tue Feb 11 2020 jmassaguerpla@suse.com
- Update to version 1.0.5:
  * Fix release number in rpms
  * Fix changelog
  * Bump version to 1.0.5
  * Add pkg-config package to fix build
  * Bump version to 1.0.4
  * Update DSL to output the first element instead of the last in case of failure
  * opensuse-leap: ensure /mnt is writeable by the unprivileged user
  * mk/nvidia-modprobe: fix parallel build issue
  * add support for openSUSE Leap 15
  * Add initial support for Optix
  * Add libnvidia-container-fix-revision.patch
